@@ -117,15 +117,18 @@ def render_xls(filename, workbook):
     workbook.save(response)
     return response
 
-def append_vendor_parts(vendors, ww, part):
+def append_vendor_parts(vendors, ww, part, style=None):
     vps = Vendor_Part.objects.filter(part_id=part.id)
+    for vp in vps:
+        if vp.vendor not in vendors:
+            vendors.append(vp.vendor)
     for v in vendors:
         vpn = ''
         for vp in vps:
             if vp.vendor.id == v.id:
                 vpn = vp.vendor_pn
                 break
-        ww.append(vpn)
+        ww.append(vpn, style)
 
 @permission_required(perms.VIEW)
 def part_bom_export(request, pk):
@@ -153,23 +156,15 @@ def part_bom_export(request, pk):
         Style(font=Font(FONT_NAME, FONT_SIZE), fill=gray95),
     ]
 
-    pids = [item.comp.id for item in assy_items]
-    vendors = Vendor.objects.filter(vendor_part__part_id__in=pids).distinct()
-
     cols = [('Idx', 6), ('PN', 10), ('Substitute PN', 13),
             ('Manufacturer', 24), ('Manufacturer PN', 31),
             ('Value', 8), ('Qty', 8),
             ('Price', 12), ('Refdes', 64), ('Description', 24)]
-    for v in vendors:
-        cols.append((v.name, 24))
-    for cspec in cols:
-        ww.append(cspec[0])
-        ws.column_dimensions[get_column_letter(ww.col)].width = cspec[1]
-    style_title.apply(ws.row_dimensions[ww.row])
     ww.next_row()
 
     sub_style_idx = 0
     idx = 1
+    vendors = []
     for item in assy_items:
         best_part = item.comp.best_part()
         refdes = ', '.join(sorted(item.refdes.split(',')))
@@ -192,8 +187,8 @@ def part_bom_export(request, pk):
                   style.copy(number_format='$ #,##0.000'))
         ww.append(refdes)
         ww.append(best_part.descr)
-        style.apply(ws.row_dimensions[ww.row])
         append_vendor_parts(vendors, ww, best_part)
+        style.apply(ws.row_dimensions[ww.row])
         ww.next_row()
 
         # add substitute rows, if any:
@@ -208,11 +203,19 @@ def part_bom_export(request, pk):
             ww.append(None, style)	# skip over Price
             ww.append(None, style)	# skip over Refdes
             ww.append(sub.descr, style)
-            append_vendor_parts(vendors, ww, sub)
+            append_vendor_parts(vendors, ww, sub, style)
             ww.next_row()
         idx += 1
     ww.next_row()
     ww.append('End of BOM', style_comment)
+
+    ww.set_row(1)
+    for v in vendors:
+        cols.append((v.name, 24))
+    for cspec in cols:
+        ww.append(cspec[0])
+        ws.column_dimensions[get_column_letter(ww.col)].width = cspec[1]
+    style_title.apply(ws.row_dimensions[ww.row])
     return render_xls(slugify(ws.title), wb)
 
 @permission_required(perms.VIEW)
