@@ -279,6 +279,10 @@ class BOM:
         where SCHEMATIC_NAME is the name of the schematic and FLAVOR is
         the name of the selected flavor (if any).
 
+        Returns a pair containing the EPIC assembly part that was
+        created/updated for the BOM and a boolean which is True if the
+        assembly part created (False if it was updated).
+
         '''
         assembly_name = 'bom:' + self.schematic_name + self.revision
         if self.flavor is not None:
@@ -348,10 +352,7 @@ class BOM:
         except webapi.Error as e:
             raise Error('Failed to save assembly items.', assy_items) from e
 
-        log.info('%s part %s (%s %s) with %d components',
-                 'updated' if old_assy else 'created',
-                 format_part_number(assembly_part.id),
-                 assembly_part.mfg, assembly_part.mfg_pn, len(self.comps))
+        return (assembly_part, not old_assy)
 
     def save_as_csv(self, filename, **kwargs):
         '''Save the BOM as a CSV text file.  See epic.kicad.csv.write() for a
