@@ -148,7 +148,7 @@ class Part(models.Model):
                                    verbose_name='Substitutes',
                                    help_text='List of other parts that are '
                                    '(identical) substitutes for this part.',
-                                   on_delete=models.CASCADE)
+                                   on_delete=models.PROTECT)
     last_bom_mod_type = models.IntegerField(choices=Enum.LAST_MOD_CHOICES,
                                             default=Enum.LAST_MOD_TYPE_USER,
                                             blank=False)
@@ -156,7 +156,7 @@ class Part(models.Model):
                                          help_text='Name of entity '
                                          'which last modified this part.')
     datasheet = models.ForeignKey(Datasheet, null=True, blank=True,
-                                  on_delete=models.CASCADE)
+                                  on_delete=models.PROTECT)
     notes = models.TextField(blank=True, default='', help_text='Notes '
                              'regarding this part.')
 
@@ -455,7 +455,7 @@ class Delta(models.Model):
     """
     part = models.ForeignKey(Part, verbose_name='Part #',
                              help_text='The part whose quantity gets '
-                             'adjusted.', on_delete=models.CASCADE)
+                             'adjusted.', on_delete=models.PROTECT)
     is_absolute = models.BooleanField(verbose_name='Absolute Adjustment',
                                       default=False,
                                       help_text='If set, the adjustment is '
@@ -465,7 +465,7 @@ class Delta(models.Model):
                               'quantity should be adjusted by.')
     txtn = models.ForeignKey('Transaction', verbose_name='Transaction #',
                              on_delete=models.CASCADE)
-    warehouse = models.ForeignKey(Warehouse, on_delete=models.CASCADE)
+    warehouse = models.ForeignKey(Warehouse, on_delete=models.PROTECT)
 
     class Meta:
         indexes = [
@@ -500,7 +500,7 @@ class Assembly_Item(models.Model):
     comp = models.ForeignKey(Part, related_name='assembly_item_comp',
                              verbose_name='Component Part #',
                              help_text='The part number of the component of '
-                             'this item.', on_delete=models.CASCADE)
+                             'this item.', on_delete=models.PROTECT)
     qty = models.PositiveIntegerField(help_text='The quantity of this '
                                       'component required by the assembly.')
     refdes = models.TextField(blank=True, default='',
@@ -541,7 +541,7 @@ class Line_Item(models.Model):
     txtn = models.ForeignKey('Transaction', verbose_name='Transaction #',
                              on_delete=models.CASCADE)
     part = models.ForeignKey(Part, verbose_name='Part #',
-                             on_delete=models.CASCADE)
+                             on_delete=models.PROTECT)
     qty = models.PositiveIntegerField(help_text='The quantity of this part.')
     line_cost = models.DecimalField(max_digits=9, decimal_places=2,
                                     verbose_name='Amount',
@@ -605,7 +605,7 @@ class Transaction(models.Model):
                                   verbose_name='Warehouse',
                                   help_text='The (destination) warehouse '
                                   'this transaction applies to.',
-                                  on_delete=models.CASCADE)
+                                  on_delete=models.PROTECT)
     notes = models.TextField(blank=True,
                              verbose_name='Notes',
                              help_text='Comments and notes for this '
@@ -750,7 +750,7 @@ class Order(Transaction):
                                  verbose_name='Order Status')
     vendor = models.ForeignKey(Vendor, help_text='The name of the '
                                'vendor (distributor) where the order '
-                               'was placed.', on_delete=models.CASCADE)
+                               'was placed.', on_delete=models.PROTECT)
 
     def __str__(self):
         return '%u' % (self.id)
@@ -793,12 +793,12 @@ class Shipment(Transaction):
                              null=True, blank=True,
                              help_text='For an order shipment, the '
                              'order that resulted in this shipment.',
-                             on_delete=models.CASCADE)
+                             on_delete=models.PROTECT)
     from_warehouse = models.ForeignKey(Warehouse, null=True, blank=True,
                                        help_text='For an inter-warehouse '
                                        'shipment, the warehouse '
                                        'the shipment originates from.',
-                                       on_delete=models.CASCADE)
+                                       on_delete=models.PROTECT)
     cost_freight = models.DecimalField(max_digits=9, decimal_places=2,
                                        verbose_name='Freight Cost',
                                        validators=[MinValueValidator(
@@ -838,7 +838,7 @@ class Shipment(Transaction):
 
     def html_tracking_links(self):
         trk_list = self.tracking.split(',')
-        url_pattern = 'https://www.packagetrackr.com/track/%s'
+        url_pattern = 'https://pkge.net/parcel/%s'
         result = []
         for trk in trk_list:
             trk = trk.strip()
@@ -1060,9 +1060,9 @@ class Stock_Cache_Item(models.Model):
                                   verbose_name='Warehouse',
                                   help_text='The warehouse stocking '
                                   'this part.',
-                                  on_delete=models.CASCADE)
+                                  on_delete=models.PROTECT)
     part = models.ForeignKey(Part, verbose_name='Part #',
-                             on_delete=models.CASCADE)
+                             on_delete=models.PROTECT)
     qty = models.IntegerField(help_text='The quantity of this part.')
 
     class Meta:
