@@ -80,7 +80,7 @@ import sexpdata
 
 # Please replace 'epic-sample' with the name of your Django project:
 os.environ.setdefault('DJANGO_SETTINGS_MODULE',
-                      'epic-sample.epic-sample.settings')
+                      'epic_sample.epic-sample.settings')
 
 import django
 django.setup()
@@ -569,9 +569,9 @@ def main():
             title_block = sheet.find('title_block')
             if title_block is not None:
                 if revision == '':
-                    rev = title_block.find('rev')
-                    if rev and rev.text:
-                        revision = '-rev' + rev.text.lstrip().rstrip()
+                    rev = title_block.findtext('rev')
+                    if rev:
+                        revision = '-rev' + rev.lstrip().rstrip()
                 sources.append(title_block.find('source').text)
 
     if not args.no_update_footprints:
